@@ -4,8 +4,8 @@ from xpandas.execute import *
 
 
 def get_cmd():
-    cmd_dict = {'s': '将csv均分为N个csv',
-                'c': '每N行切分为一个csv',
+    cmd_dict = {'c': '将csv均分为N个csv',
+                's': '每N行切分为一个csv',
                 't': '按csv中某列的值Top N行'}
     while True:
         print('Commands:')
@@ -28,9 +28,9 @@ def run(csv):
     if cmd == 's':
         split_csv(df, csv)
     elif cmd == 'c':
-        cut_csv(df, csv)
+        chunk_csv(df, csv)
     elif cmd == 't':
-        pass
+        top_csv(df, csv)
 
 
 if __name__ == '__main__':
